
.. py:currentmodule:: pythreejs

IcosahedronGeometry
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: IcosahedronGeometry(radius=1, detail=0, )
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.BaseGeometry`.

    Three.js docs: https://threejs.org/docs/#api/geometries/IcosahedronGeometry


    .. py:attribute:: radius

        .. sourcecode:: python

            CFloat(1, allow_none=False).tag(sync=True)

    .. py:attribute:: detail

        .. sourcecode:: python

            CInt(0, allow_none=False).tag(sync=True)

